diff --git a/indra/llcommon/indra_constants.h b/indra/llcommon/indra_constants.h
index fab4f11eb..86fbba80c 100644
--- a/indra/llcommon/indra_constants.h
+++ b/indra/llcommon/indra_constants.h
@@ -140,19 +140,6 @@ const U32 DEFAULT_CGI_SERVICES_PORT = 12045;
// on a single host for map tile generation. JC
const U32 DEFAULT_MAPSERVER_PORT = 12124;
-const char LAND_LAYER_CODE = 'L';
-const char WATER_LAYER_CODE = 'W';
-const char WIND_LAYER_CODE = '7';
-const char CLOUD_LAYER_CODE = '8';
-
-// Aurora Sim
-// Extended land layer for Aurora Sim
-const char AURORA_LAND_LAYER_CODE = 'M';
-const char AURORA_WATER_LAYER_CODE = 'X';
-const char AURORA_WIND_LAYER_CODE = '9';
-const char AURORA_CLOUD_LAYER_CODE = ':';
-// Aurora Sim
-
enum ETerrainBrushType
{
// the valid brush numbers cannot be reordered, because they
diff --git a/indra/llrender/llimagegl.cpp b/indra/llrender/llimagegl.cpp
index 968897dde..05bbebe85 100644
--- a/indra/llrender/llimagegl.cpp
+++ b/indra/llrender/llimagegl.cpp
@@ -572,7 +572,7 @@ void LLImageGL::setSize(S32 width, S32 height, S32 ncomponents, S32 discard_leve
// Check if dimensions are a power of two!
if (!checkSize(width,height))
{
- LL_WARNS() << llformat("Texture has non power of two dimension: %dx%d",width,height) << " Unless on Aurora-Sim, beware." << LL_ENDL;
+ LL_WARNS() << llformat("Texture has non power of two dimension: %dx%d",width,height) << " Unless on WhiteCore, beware." << LL_ENDL;
}
if (mTexName)
diff --git a/indra/newview/hippogridmanager.cpp b/indra/newview/hippogridmanager.cpp
index 5295aac95..f1f13906e 100644
--- a/indra/newview/hippogridmanager.cpp
+++ b/indra/newview/hippogridmanager.cpp
@@ -105,9 +105,9 @@ void HippoGridInfo::setPlatform(const std::string& platform)
for (unsigned i=0; i= PLATFORM_LAST))
diff --git a/indra/newview/hippogridmanager.h b/indra/newview/hippogridmanager.h
index 450cc35f7..73eeca2d7 100644
--- a/indra/newview/hippogridmanager.h
+++ b/indra/newview/hippogridmanager.h
@@ -26,7 +26,7 @@ class HippoGridInfo
public:
enum Platform {
PLATFORM_OTHER = 0,
- PLATFORM_AURORA,
+ PLATFORM_WHITECORE,
PLATFORM_OPENSIM,
PLATFORM_SECONDLIFE,
PLATFORM_LAST
@@ -35,8 +35,8 @@ public:
explicit HippoGridInfo(const std::string& gridName);
Platform getPlatform() { return mPlatform; }
- bool isOpenSimulator() const { return (mPlatform == PLATFORM_OPENSIM || mPlatform == PLATFORM_AURORA); }
- bool isAurora() const { return (mPlatform == PLATFORM_AURORA); }
+ bool isOpenSimulator() const { return (mPlatform == PLATFORM_OPENSIM || mPlatform == PLATFORM_WHITECORE); }
+ bool isWhiteCore() const { return (mPlatform == PLATFORM_WHITECORE); }
bool isSecondLife() const { return (mPlatform == PLATFORM_SECONDLIFE); }
bool isAvination() const { return mIsInAvination; }
bool isInProductionGrid() const { llassert(mPlatform == PLATFORM_SECONDLIFE); return mIsInProductionGrid; } // Should only be called if isSecondLife() returns true.
diff --git a/indra/newview/hippolimits.cpp b/indra/newview/hippolimits.cpp
index 8e7462511..929686f70 100644
--- a/indra/newview/hippolimits.cpp
+++ b/indra/newview/hippolimits.cpp
@@ -21,8 +21,8 @@ void HippoLimits::setLimits()
{
if (gHippoGridManager->getConnectedGrid()->getPlatform() == HippoGridInfo::PLATFORM_SECONDLIFE) {
setSecondLifeLimits();
- } else if (gHippoGridManager->getConnectedGrid()->getPlatform() == HippoGridInfo::PLATFORM_AURORA) {
- setAuroraLimits();
+ } else if (gHippoGridManager->getConnectedGrid()->getPlatform() == HippoGridInfo::PLATFORM_WHITECORE) {
+ setWhiteCoreLimits();
} else {
setOpenSimLimits();
}
@@ -66,7 +66,7 @@ void HippoLimits::setOpenSimLimits()
}
}
-void HippoLimits::setAuroraLimits()
+void HippoLimits::setWhiteCoreLimits()
{
setMaxAgentGroups();
mMaxPrimScale = 8192.0f;
diff --git a/indra/newview/hippolimits.h b/indra/newview/hippolimits.h
index 0c119cd34..6c48fc298 100644
--- a/indra/newview/hippolimits.h
+++ b/indra/newview/hippolimits.h
@@ -27,7 +27,7 @@ private:
void setMaxAgentGroups();
void setOpenSimLimits();
- void setAuroraLimits();
+ void setWhiteCoreLimits();
void setSecondLifeLimits();
};
diff --git a/indra/newview/llmaniptranslate.cpp b/indra/newview/llmaniptranslate.cpp
index 4b8597ff0..cc17802f9 100644
--- a/indra/newview/llmaniptranslate.cpp
+++ b/indra/newview/llmaniptranslate.cpp
@@ -542,7 +542,7 @@ BOOL LLManipTranslate::handleHover(S32 x, S32 y, MASK mask)
{
F32 max_drag_distance = gSavedSettings.getF32("MaxDragDistance");
- if (gHippoGridManager->getConnectedGrid()->isAurora())
+ if (gHippoGridManager->getConnectedGrid()->isWhiteCore())
max_drag_distance = llmin(10000.f, max_drag_distance);
if (relative_move.magVecSquared() > max_drag_distance * max_drag_distance)
diff --git a/indra/newview/llmarketplacefunctions.cpp b/indra/newview/llmarketplacefunctions.cpp
index d8c921b9b..23c46561b 100644
--- a/indra/newview/llmarketplacefunctions.cpp
+++ b/indra/newview/llmarketplacefunctions.cpp
@@ -84,7 +84,7 @@ static std::string getMarketplaceDomain()
else
{
// TODO: Find out if OpenSim, and Avination adopted any outbox stuffs, if so code HippoGridManager for this
- // Aurora grid has not.
+ // WhiteCore has not.
// For now, set domain on other grids to the loginUri domain, so we don't harass LL web services.
domain = getLoginUriDomain(); //gHippoGridManager->getCurrentGrid()->getMarketPlaceDomain();
}
diff --git a/indra/newview/llpanellogin.cpp b/indra/newview/llpanellogin.cpp
index 71acaaafd..7906493ef 100644
--- a/indra/newview/llpanellogin.cpp
+++ b/indra/newview/llpanellogin.cpp
@@ -103,7 +103,7 @@ static bool nameSplit(const std::string& full, std::string& first, std::string&
return false;
first = fragments[0];
last = (fragments.size() == 1) ?
- gHippoGridManager->getCurrentGrid()->isAurora() ? "" : "Resident" :
+ gHippoGridManager->getCurrentGrid()->isWhiteCore() ? "" : "Resident" :
fragments[1];
return (fragments.size() <= 2);
}
@@ -843,7 +843,7 @@ void LLPanelLogin::loadLoginPage()
{
params["grid"] = gHippoGridManager->getCurrentGrid()->getGridNick();
}
- else if (gHippoGridManager->getCurrentGrid()->getPlatform() == HippoGridInfo::PLATFORM_AURORA)
+ else if (gHippoGridManager->getCurrentGrid()->getPlatform() == HippoGridInfo::PLATFORM_WHITECORE)
{
params["grid"] = LLViewerLogin::getInstance()->getGridLabel();
}
diff --git a/indra/newview/llviewerparcelmgr.cpp b/indra/newview/llviewerparcelmgr.cpp
index c528e3f8f..069f65310 100644
--- a/indra/newview/llviewerparcelmgr.cpp
+++ b/indra/newview/llviewerparcelmgr.cpp
@@ -145,7 +145,7 @@ LLViewerParcelMgr::LLViewerParcelMgr()
mCollisionParcel = new LLParcel();
// Aurora Sim
- mParcelsPerEdge = S32(8192.f / PARCEL_GRID_STEP_METERS); // 8192 is the maximum region size on Aurora and solves the audio problem.
+ mParcelsPerEdge = S32(8192.f / PARCEL_GRID_STEP_METERS); // 8192 is the maximum region size on WhiteCore and solves the audio problem.
//mParcelsPerEdge = S32( REGION_WIDTH_METERS / PARCEL_GRID_STEP_METERS );
// Aurora Sim
mHighlightSegments = new U8[(mParcelsPerEdge+1)*(mParcelsPerEdge+1)];
diff --git a/indra/newview/llvlmanager.cpp b/indra/newview/llvlmanager.cpp
index d570428bd..b4ec788f7 100644
--- a/indra/newview/llvlmanager.cpp
+++ b/indra/newview/llvlmanager.cpp
@@ -42,6 +42,16 @@
#include "llframetimer.h"
#include "llsurface.h"
+const char LAND_LAYER_CODE = 'L';
+const char WATER_LAYER_CODE = 'W';
+const char WIND_LAYER_CODE = '7';
+const char CLOUD_LAYER_CODE = '8';
+
+const char WHITECORE_LAND_LAYER_CODE = 'M';
+const char WHITECORE_WATER_LAYER_CODE = 'X';
+const char WHITECORE_WIND_LAYER_CODE = '9';
+const char WHITECORE_CLOUD_LAYER_CODE = ':';
+
LLVLManager gVLManager;
LLVLManager::~LLVLManager()
@@ -56,33 +66,22 @@ LLVLManager::~LLVLManager()
void LLVLManager::addLayerData(LLVLData *vl_datap, const S32 mesg_size)
{
-// Aurora Sim
- //if (LAND_LAYER_CODE == vl_datap->mType)
- if (LAND_LAYER_CODE == vl_datap->mType || AURORA_LAND_LAYER_CODE == vl_datap->mType)
-// Aurora Sim
+ if (LAND_LAYER_CODE == vl_datap->mType || WHITECORE_LAND_LAYER_CODE == vl_datap->mType)
{
mLandBits += mesg_size * 8;
}
-// Aurora Sim
- //else if (WIND_LAYER_CODE == vl_datap->mType)
- else if (WIND_LAYER_CODE == vl_datap->mType || AURORA_WIND_LAYER_CODE == vl_datap->mType)
-// Aurora Sim
- {
- mWindBits += mesg_size * 8;
- }
-// Aurora Sim
- //else if (CLOUD_LAYER_CODE == vl_datap->mType)
- else if (CLOUD_LAYER_CODE == vl_datap->mType || AURORA_CLOUD_LAYER_CODE == vl_datap->mType)
-// Aurora Sim
- {
- mCloudBits += mesg_size * 8;
- }
-// Aurora Sim
- else if (WATER_LAYER_CODE == vl_datap->mType || AURORA_CLOUD_LAYER_CODE == vl_datap->mType)
+ else if (WATER_LAYER_CODE == vl_datap->mType || WHITECORE_CLOUD_LAYER_CODE == vl_datap->mType)
{
mWaterBits += mesg_size * 8;
}
-// Aurora Sim
+ else if (WIND_LAYER_CODE == vl_datap->mType || WHITECORE_WIND_LAYER_CODE == vl_datap->mType)
+ {
+ mWindBits += mesg_size * 8;
+ }
+ else if (CLOUD_LAYER_CODE == vl_datap->mType || WHITECORE_CLOUD_LAYER_CODE == vl_datap->mType)
+ {
+ mCloudBits += mesg_size * 8;
+ }
else
{
LL_ERRS() << "Unknown layer type!" << (S32)vl_datap->mType << LL_ENDL;
@@ -108,19 +107,16 @@ void LLVLManager::unpackData(const S32 num_packets)
{
datap->mRegionp->getLand().decompressDCTPatch(bit_pack, &goph, FALSE);
}
-// Aurora Sim
- else if (AURORA_LAND_LAYER_CODE == datap->mType)
+ else if (WHITECORE_LAND_LAYER_CODE == datap->mType)
{
datap->mRegionp->getLand().decompressDCTPatch(bit_pack, &goph, TRUE);
}
- //else if (WIND_LAYER_CODE == datap->mType)
- else if (WIND_LAYER_CODE == datap->mType || AURORA_WIND_LAYER_CODE == datap->mType)
-// Aurora Sim
+ else if (WIND_LAYER_CODE == datap->mType || WHITECORE_WIND_LAYER_CODE == datap->mType)
{
datap->mRegionp->mWind.decompress(bit_pack, &goph);
}
- else if (CLOUD_LAYER_CODE == datap->mType || AURORA_CLOUD_LAYER_CODE == datap->mType)
+ else if (CLOUD_LAYER_CODE == datap->mType || WHITECORE_CLOUD_LAYER_CODE == datap->mType)
{
#if ENABLE_CLASSIC_CLOUDS
datap->mRegionp->mCloudLayer.decompress(bit_pack, &goph);
@@ -156,6 +152,11 @@ S32 LLVLManager::getCloudBits() const
return mCloudBits;
}
+S32 LLVLManager::getWaterBits() const
+{
+ return mWaterBits;
+}
+
S32 LLVLManager::getTotalBytes() const
{
return mLandBits + mWindBits + mCloudBits;
@@ -189,6 +190,6 @@ LLVLData::LLVLData(LLViewerRegion *regionp, const S8 type, U8 *data, const S32 s
LLVLData::~LLVLData()
{
delete [] mData;
- mData = NULL;
- mRegionp = NULL;
+ mData = nullptr;
+ mRegionp = nullptr;
}
diff --git a/indra/newview/llvlmanager.h b/indra/newview/llvlmanager.h
index 153abfa53..03d26d0db 100644
--- a/indra/newview/llvlmanager.h
+++ b/indra/newview/llvlmanager.h
@@ -54,6 +54,7 @@ public:
S32 getLandBits() const;
S32 getWindBits() const;
S32 getCloudBits() const;
+ S32 getWaterBits() const;
void resetBitCounts();
@@ -64,9 +65,7 @@ protected:
U32 mLandBits;
U32 mWindBits;
U32 mCloudBits;
-// Aurora Sim
U32 mWaterBits;
-// Aurora Sim
};
class LLVLData
@@ -76,10 +75,10 @@ public:
const S8 type, U8 *data, const S32 size);
~LLVLData();
- S8 mType;
- U8 *mData;
- S32 mSize;
LLViewerRegion *mRegionp;
+ U8 *mData;
+ S8 mType;
+ S32 mSize;
};
extern LLVLManager gVLManager;
diff --git a/indra/newview/llworldmap.cpp b/indra/newview/llworldmap.cpp
index 8f33a56ac..ceb147443 100644
--- a/indra/newview/llworldmap.cpp
+++ b/indra/newview/llworldmap.cpp
@@ -95,8 +95,8 @@ LLSimInfo::LLSimInfo(U64 handle)
void LLSimInfo::setLandForSaleImage (LLUUID image_id)
{
- const bool is_aurora = gHippoGridManager->getConnectedGrid()->isAurora();
- if (is_aurora && mMapImageID[SIM_LAYER_OVERLAY].isNull() && image_id.notNull() && gTextureList.findImage(image_id))
+ const bool is_whitecore = gHippoGridManager->getConnectedGrid()->isWhiteCore();
+ if (is_whitecore && mMapImageID[SIM_LAYER_OVERLAY].isNull() && image_id.notNull() && gTextureList.findImage(image_id))
LLAppViewer::getTextureCache()->removeFromCache(image_id);
mMapImageID[SIM_LAYER_OVERLAY] = image_id;
@@ -105,7 +105,7 @@ void LLSimInfo::setLandForSaleImage (LLUUID image_id)
if (mMapImageID[SIM_LAYER_OVERLAY].notNull())
{
mLayerImage[SIM_LAYER_OVERLAY] = LLViewerTextureManager::getFetchedTexture(mMapImageID[SIM_LAYER_OVERLAY], FTT_DEFAULT, MIPMAP_TRUE, LLGLTexture::BOOST_MAP, LLViewerTexture::LOD_TEXTURE);
- if (is_aurora) mLayerImage[SIM_LAYER_OVERLAY]->forceImmediateUpdate();
+ if (is_whitecore) mLayerImage[SIM_LAYER_OVERLAY]->forceImmediateUpdate();
mLayerImage[SIM_LAYER_OVERLAY]->setAddressMode(LLTexUnit::TAM_CLAMP);
}
else
diff --git a/indra/newview/skins/default/xui/de/strings.xml b/indra/newview/skins/default/xui/de/strings.xml
index 8d1ab98ee..495e6d8ef 100644
--- a/indra/newview/skins/default/xui/de/strings.xml
+++ b/indra/newview/skins/default/xui/de/strings.xml
@@ -1291,8 +1291,8 @@ Sets the given permission mask to the new value on the root object the task is a
Please keep LL-LSL above this section
** DATA SOURCES **
OpenSim OS Functions: \OpenSim\Region\ScriptEngine\Shared\Api\Interface\IOSSL_Api.cs
- Aurora-Sim AA Functions: \Aurora\AuroraDotNetEngine\APIs\AA_API.cs
- Aurora-Sim BOT Functions: \Aurora\BotManager\Bot_API.cs
+ WhiteCore AA Functions: \WhiteCore\ScriptEngine\DotNetEngine\APIs\AA\AA_API.cs
+ WhiteCore BOT Functions: \WhiteCore\BotManager\Bot_API.cs
-->
osSetDynamicTextureURL(key dynamicID, string contentType, string url, string extraParams, integer timer )
@@ -1622,199 +1622,139 @@ Set the current WindLight scene directed at a specific avatar. Estate managers a
list lsGetWindlightScene(list rules)
Get the current WindLight settings.
(Reguires LightShare Enabled Viewer)
-
osReturnObject(key userID)
-Returns object to specified avatars UUID.
-(Aurora-Sim only)
+Returns object to specified avatars UUID.
osReturnObjects(float Parameter)
-Returns group of objects. Parameter's are numeric, values are owner objects = 0, everyone except owner objects = 1, group objects = 2.
-(Aurora-Sim only)
+Returns group of objects. Parameter's are numeric, values are owner objects = 0, everyone except owner objects = 1, group objects = 2.
osShutDown()
-Shut's down current Simulator. Authorized Admin Only by config.
-(Aurora-Sim only)
+Shut's down current Simulator. Authorized Admin Only by config.
osAddAgentToGroup(key avatarID, string group_name, string role_name)
-Adds an avatar to a group. Where group_name = name of the target group, role_name = role to assign within the group.
-(Aurora-Sim only)
+Adds an avatar to a group. Where group_name = name of the target group, role_name = role to assign within the group.
osRezObject(string inventory, vector position, vector velocity, rotation rot, integer param, integer isRezAtRoot, integer doRecoil, integer SetDieAtEdge, integer CheckPos)
Where inventory = object to rez. Position = vector to rez object. Velocity = initial velocity. Rot = initial rotation. Param = onrez event.
IzAtRoot = TRUE/FALSE flag changes llRezAtRoot to llRezObject. doRecoil =TRUE/FALSE to push avatar. SetDieAtEdge = TRUE/FALSE for rezzed object to die at edge of region.
-CheckPos = TRUE/FALSE enable/disable 10m rez limit.
-(Aurora-Sim only)
+CheckPos = TRUE/FALSE enable/disable 10m rez limit.
aaSetCloudDensity(float density)
-AaSetCloudDensity(0.5) Where float density values are 0.0 = no cloud to 1.0 = 100% cloud.
-(Aurora-Sim only)
+AaSetCloudDensity(0.5) Where float density values are 0.0 = no cloud to 1.0 = 100% cloud.
aUpdateDatabase(string Key, string value, string token)
-Where Key = database field name, xmlDataToPutIntoTheDatabase = serialized XML data, Token = data-password
-(Aurora-Sim only)
+Where Key = database field name, xmlDataToPutIntoTheDatabase = serialized XML data, Token = data-password
aaQueryDatabase(string Key, string Token)
Returns a list with first value is the token, the second the Key, and the third the value
-Where Key = database field name, Token = data-password
-(Aurora-Sim only)
+Where Key = database field name, Token = data-password
aaDeserializeXMLValues(string xmlData)
-Returns a list of Values from XML data. Where xmlData = xml formatted data Values.
-(Aurora-Sim only)
+Returns a list of Values from XML data. Where xmlData = xml formatted data Values.
aaDeserializeXMLKeys(string xmlData)
-Returns a list of keys from XML data. Where xmlData = xml formatted data keys.
-(Aurora-Sim only)
+Returns a list of keys from XML data. Where xmlData = xml formatted data keys.
aaSetConeOfSilence(float radius)
-Where radius = metres radius from centre of scripted item. This creates an area that sounds can only be heard by the people within the area(radius) and not heard outside and visa-versa.
-(Aurora-Sim only)
+Where radius = metres radius from centre of scripted item. This creates an area that sounds can only be heard by the people within the area(radius) and not heard outside and visa-versa.
aaSerializeXML(list keys, list values)
-Returns xml formatted string of the keys and values. Where keys = list of keys in the database, values = fields to retrieve from database.
-(Aurora-Sim only)
+Returns xml formatted string of the keys and values. Where keys = list of keys in the database, values = fields to retrieve from database.
aaGetTeam(key uuid)
-Returns a string of avatars team name. Where uuid = avatar key.
-(Aurora-Sim only)
+Returns a string of avatars team name. Where uuid = avatar key.
aaGetHealth(key uuid)
-Returns float value (0.0 to 100.0) of current health. Where uuid = avatar key.
-(Aurora-Sim only)
+Returns float value (0.0 to 100.0) of current health. Where uuid = avatar key.
aaJoinCombat(key uuid)
-Where uuid = avatar key. If (PERMISSION_COMBAT == PERMISSION_COMBAT) and permission is granted then join combat.
-(Aurora-Sim only)
+Where uuid = avatar key. If (PERMISSION_COMBAT == PERMISSION_COMBAT) and permission is granted then join combat.
aaLeaveCombat(key uuid)
-Where uuid = avatar key.
-(Aurora-Sim only)
+Where uuid = avatar key.
aaJoinCombatTeam(key uuid, string team)
-Where uuid = key of avatar, team = string of the team name.
-(Aurora-Sim only)
+Where uuid = key of avatar, team = string of the team name.
aaRequestCombatPermission(key ID)
Where ID = avatar uuid. Requests target avatar for Permissions to enter into combat mode.
-Raises a run_time_permissions event. (PERMISSION_COMBAT == PERMISSION_COMBAT).
-(Aurora-Sim only)
+Raises a run_time_permissions event. (PERMISSION_COMBAT == PERMISSION_COMBAT).
aaThawAvatar(key ID)
-Where ID = avatar uuid. If combat permission are granted then avatar can be un-frozen (movement re-enabled).
-(Aurora-Sim only)
+Where ID = avatar uuid. If combat permission are granted then avatar can be un-frozen (movement re-enabled).
aaFreezeAvatar(key ID)
-Where ID = avatar uuid. If combat permission are granted then avatar can be frozen (no movement).
-(Aurora-Sim only)
+Where ID = avatar uuid. If combat permission are granted then avatar can be frozen (no movement).
aaGetTeamMembers(string team)
-Return a list of team members. Where team = string of team name.
-(Aurora-Sim only)
+Return a list of team members. Where team = string of team name.
POLYMORPHIC FUNCTION.
aaGetLastOwner(string PrimID) returns last owner UUID of PrimID where PrimID = uuid of prim.
-AaGetLastOwner() returns last owner uuid of prim containg script.
-(Aurora-Sim only)
+AaGetLastOwner() returns last owner uuid of prim containg script.
aaSayDistance(integer channelID, float Distance, string text)
-Where channelID = channel to say on, Distance = float in meters for distance to say, text = string to say.
-(Aurora-Sim only)
+Where channelID = channel to say on, Distance = float in meters for distance to say, text = string to say.
aaSayTo(key userID, string text)
-Where userID = avatar key, text = string msg. Similar to llOwnerSay but can be directly targeted to an avatar.
-(Aurora-Sim only)
+Where userID = avatar key, text = string msg. Similar to llOwnerSay but can be directly targeted to an avatar.
aaGetWalkDisabled(key ID)
-Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
-(Aurora-Sim only)
+Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
aaSetWalkDisabled(key ID, integer Value)
-Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables walk, forcing avatar to fly.
-(Aurora-Sim only)
+Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables walk, forcing avatar to fly.
aaGetFlyDisabled(key ID)
-Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
-(Aurora-Sim only)
+Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
aaSetFlyDisabled(key ID, integer Value)
-Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables flying, forcing avatar to walk.
-(Aurora-Sim only)
+Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables flying, forcing avatar to walk.
aaAvatarFullName2Key(string FullName)
-Returns the avatar uuid from their fullname. Where FullName = "Firstname Lastname”.
-(Aurora-Sim only)
+Returns the avatar uuid from their fullname. Where FullName = "Firstname Lastname”.
aaRaiseError(string message)
-Allows you to have errors that end the execution of the event and fire another event in the script.
-(Aurora-Sim only)
+Allows you to have errors that end the execution of the event and fire another event in the script.
aaGetText()
-Returns a string of the hover text of an object.
-(Aurora-Sim only)
+Returns a string of the hover text of an object.
aaGetTextColor()
-Returns the hovertext color in rotation. Use Ex: rotation color = aaGetTextColor() to separate color.x, color.y, color.z, color.s Where s = value of alpha in llSetText.
-(Aurora-Sim only)
+Returns the hovertext color in rotation. Use Ex: rotation color = aaGetTextColor() to separate color.x, color.y, color.z, color.s Where s = value of alpha in llSetText.
aaSetEnv(string EnvName, list Value)
Sets environment values. Where EnvName = ENABLE_GRAVITY, GRAVITY_FORCE_X, GRAVITY_FORCE_Y, GRAVITY_FORCE_Z, ADD_GRAVITY_POINT, ADD_GRAVITY_FORCE, START_TIME_REVERSAL_SAVING,
-STOP_TIME_REVERSAL_SAVING, START_TIME_REVERSAL, STOP_TIME_REVERSAL.
-(Aurora-Sim only)
+STOP_TIME_REVERSAL_SAVING, START_TIME_REVERSAL, STOP_TIME_REVERSAL.
aaGetIsInfiniteRegion()
-Returns TRUE or FALSE if region is an infinite region.
-(Aurora-Sim only)
+Returns TRUE or FALSE if region is an infinite region.
aaSetCharacterStat( ID, StatName, statValue)
-Sets Character Stats. Where ID = avatar uuid, StatName = stat to change, statValue the value to change it to.
-(Aurora-Sim only)
- aaAllRegionInstanceSay(integer channelID, string text)
-(Aurora-Sim only)
+Sets Character Stats. Where ID = avatar uuid, StatName = stat to change, statValue the value to change it to.
+ aaAllRegionInstanceSay(integer channelID, string text)
aaWindlightGetDayCycle()
-Returns a List of settings
-(Aurora-Sim only)
+Returns a List of settings
aaWindlightAddDayCycleFrame(float dayCyclePosition, integer dayCycleFrameToCopy)
-Returns TRUE / FALSE on success status
-(Aurora-Sim only)
+Returns TRUE / FALSE on success status
aaWindlightRemoveDayCycleFrame(int dayCycleFrame)
-Returns TRUE / FALSE on success status
-(Aurora-Sim only)
+Returns TRUE / FALSE on success status
aaWindlightSetScene(list list)
aaWindlightSetScene(integer dayCycleIndex, list list)
-Returns TRUE/FALSE on success
-(Aurora-Sim only)
+Returns TRUE/FALSE on success
aaWindlightGetScene(list rules)
aaWindlightGetScene(integer dayCycleKeyFrame, list rules)
-Returns a list
-(Aurora-Sim only)
+Returns a list
aaWindlightGetSceneIsStatic()
-Returns TRUE / FALSE
-(Aurora-Sim only)
+Returns TRUE / FALSE
aaWindlightGetSceneDayCycleKeyFrameCount()
-Returns integer value
-(Aurora-Sim only)
+Returns integer value
botGetWaitingTime(integer waitTime)
-Returns waitTime as vector.
-(Aurora-Sim only)
+Returns waitTime as vector.
botSetMap(key keyOfBot, list positions, list movementType, integer flags)
keyOfBot = bot uuid, positions = list of position vectors, movementType = corresponding list of move modes: 0 – walk, 1 – fly,
-flags = BOT_FOLLOW_FLAG_NONE and BOT_FOLLOW_FLAG_INDEFINITELY.
-(Aurora-Sim only)
+flags = BOT_FOLLOW_FLAG_NONE and BOT_FOLLOW_FLAG_INDEFINITELY.
botCreateBot(string FirstName, string LastName, key idToClone, vector startPos)
-Where FirstName and LastName = strings for new bot name. idToClone = uuid of prebuild avatar to clone OR another existing avatar. startPos = vector of starting position on region.
-(Aurora-Sim only)
+Where FirstName and LastName = strings for new bot name. idToClone = uuid of prebuild avatar to clone OR another existing avatar. startPos = vector of starting position on region.
botRemoveBot(key botID)
-Where botID = uuid of bot. Removes bot identified by botID.
-(Aurora-Sim only)
+Where botID = uuid of bot. Removes bot identified by botID.
botPauseMovement(key botID)
-Where botID = bot uuid. Pauses bot at current position.
-(Aurora-Sim only)
+Where botID = bot uuid. Pauses bot at current position.
botResumeMovement(key botID)
-Where botID = bot uuid. Resumes bot movement.
-(Aurora-Sim only)
+Where botID = bot uuid. Resumes bot movement.
botFollowAvatar(key botID, string avName, float startFollowDistance, float endFollowDistance)
-Where botID = bot uuid. AvName = sting of avatar name OR avatar uuid. StartFollowDistance = distance to start following from. EndFollowDistance = distance to stop following avatar.
-(Aurora-Sim only)
+Where botID = bot uuid. AvName = sting of avatar name OR avatar uuid. StartFollowDistance = distance to start following from. EndFollowDistance = distance to stop following avatar.
botStopFollowAvatar(key botID)
-Where botID = bot uuid. Stops bot from following an avatar.
-(Aurora-Sim only)
+Where botID = bot uuid. Stops bot from following an avatar.
botSendChatMessage(key botID, string message, integer channel, integer sayType)
-Where botID = bot uuid. Message = string msg. Channel = channel to speak on. SayType = (0=whisper, 1=say, 2=shout).
-(Aurora-Sim only)
+Where botID = bot uuid. Message = string msg. Channel = channel to speak on. SayType = (0=whisper, 1=say, 2=shout).
botSendIM(string bot, string user, string message)
-Send IM to bot.
-(Aurora-Sim only)
+Send IM to bot.
botSetShouldFly(key botID, integer ShouldFly)
-Where botID = bot uuid. ShouldFly = TRUE/FALSE. Enables or disables flight mode.
-(Aurora-Sim only)
+Where botID = bot uuid. ShouldFly = TRUE/FALSE. Enables or disables flight mode.
botSitObject(key botID, key objectID, vector offset)
-Where botID = bot uuid, objectID = uuid of object to sit on, offset = Vector for sit position (note that VECTOR_ZERO = default sit pos).
-(Aurora-Sim only)
+Where botID = bot uuid, objectID = uuid of object to sit on, offset = Vector for sit position (note that VECTOR_ZERO = default sit pos).
botStandUp(key botID)
-Where botID = bot uuid. Command bot to stand up.
-(Aurora-Sim only)
+Where botID = bot uuid. Command bot to stand up.
botTouchObject(key botID, key objectID)
-Where botID = bot uuid, objectID = object uuid. Causes bot to touch object identified.
-(Aurora-Sim only)
+Where botID = bot uuid, objectID = object uuid. Causes bot to touch object identified.
botAddTag(key botID, string tag)
-Where botID = bot uuid, tag = string tag over bot.
-(Aurora-Sim only)
+Where botID = bot uuid, tag = string tag over bot.
botGetBotsWithTag(string tag)
-Where tag = tag string to match. Return a list of bot UUID's in region with the matching tag.
-(Aurora-Sim only)
+Where tag = tag string to match. Return a list of bot UUID's in region with the matching tag.
botRemoveBotsWithTag(string tag)
-Where tag = tag string to match. Removes bot's matching the tag.
-(Aurora-Sim only)
-
+Where tag = tag string to match. Removes bot's matching the tag.
+
Currently not set
diff --git a/indra/newview/skins/default/xui/en-us/strings.xml b/indra/newview/skins/default/xui/en-us/strings.xml
index af87e8956..309840fb6 100644
--- a/indra/newview/skins/default/xui/en-us/strings.xml
+++ b/indra/newview/skins/default/xui/en-us/strings.xml
@@ -2168,8 +2168,8 @@ Sets the given permission mask to the new value on the root object the task is a
Please keep LL-LSL above this section
** DATA SOURCES **
OpenSim OS Functions: \OpenSim\Region\ScriptEngine\Shared\Api\Interface\IOSSL_Api.cs
- Aurora-Sim AA Functions: \Aurora\AuroraDotNetEngine\APIs\AA_API.cs
- Aurora-Sim BOT Functions: \Aurora\BotManager\Bot_API.cs
+ WhiteCore AA Functions: \WhiteCore\ScriptEngine\DotNetEngine\APIs\AA\AA_API.cs
+ WhiteCore BOT Functions: \WhiteCore\BotManager\Bot_API.cs
-->
@@ -2799,319 +2799,259 @@ list lsGetWindlightScene(list rules)
Get the current WindLight settings.
(Reguires LightShare Enabled Viewer)
-
osReturnObject(key userID)
Returns object to specified avatars UUID.
-(Aurora-Sim only)
osReturnObjects(float Parameter)
Returns group of objects. Parameter's are numeric, values are owner objects = 0, everyone except owner objects = 1, group objects = 2.
-(Aurora-Sim only)
osShutDown()
Shut's down current Simulator. Authorized Admin Only by config.
-(Aurora-Sim only)
osAddAgentToGroup(key avatarID, string group_name, string role_name)
Adds an avatar to a group. Where group_name = name of the target group, role_name = role to assign within the group.
-(Aurora-Sim only)
osRezObject(string inventory, vector position, vector velocity, rotation rot, integer param, integer isRezAtRoot, integer doRecoil, integer SetDieAtEdge, integer CheckPos)
Where inventory = object to rez. Position = vector to rez object. Velocity = initial velocity. Rot = initial rotation. Param = onrez event.
IzAtRoot = TRUE/FALSE flag changes llRezAtRoot to llRezObject. doRecoil =TRUE/FALSE to push avatar. SetDieAtEdge = TRUE/FALSE for rezzed object to die at edge of region.
CheckPos = TRUE/FALSE enable/disable 10m rez limit.
-(Aurora-Sim only)
aaSetCloudDensity(float density)
AaSetCloudDensity(0.5) Where float density values are 0.0 = no cloud to 1.0 = 100% cloud.
-(Aurora-Sim only)
aUpdateDatabase(string Key, string value, string token)
Where Key = database field name, xmlDataToPutIntoTheDatabase = serialized XML data, Token = data-password
-(Aurora-Sim only)
aaQueryDatabase(string Key, string Token)
Returns a list with first value is the token, the second the Key, and the third the value
Where Key = database field name, Token = data-password
-(Aurora-Sim only)
aaDeserializeXMLValues(string xmlData)
Returns a list of Values from XML data. Where xmlData = xml formatted data Values.
-(Aurora-Sim only)
aaDeserializeXMLKeys(string xmlData)
Returns a list of keys from XML data. Where xmlData = xml formatted data keys.
-(Aurora-Sim only)
aaSetConeOfSilence(float radius)
Where radius = metres radius from centre of scripted item. This creates an area that sounds can only be heard by the people within the area(radius) and not heard outside and visa-versa.
-(Aurora-Sim only)
aaSerializeXML(list keys, list values)
Returns xml formatted string of the keys and values. Where keys = list of keys in the database, values = fields to retrieve from database.
-(Aurora-Sim only)
aaGetTeam(key uuid)
Returns a string of avatars team name. Where uuid = avatar key.
-(Aurora-Sim only)
aaGetHealth(key uuid)
Returns float value (0.0 to 100.0) of current health. Where uuid = avatar key.
-(Aurora-Sim only)
aaJoinCombat(key uuid)
Where uuid = avatar key. If (PERMISSION_COMBAT == PERMISSION_COMBAT) and permission is granted then join combat.
-(Aurora-Sim only)
aaLeaveCombat(key uuid)
Where uuid = avatar key.
-(Aurora-Sim only)
aaJoinCombatTeam(key uuid, string team)
Where uuid = key of avatar, team = string of the team name.
-(Aurora-Sim only)
aaRequestCombatPermission(key ID)
Where ID = avatar uuid. Requests target avatar for Permissions to enter into combat mode.
Raises a run_time_permissions event. (PERMISSION_COMBAT == PERMISSION_COMBAT).
-(Aurora-Sim only)
aaThawAvatar(key ID)
Where ID = avatar uuid. If combat permission are granted then avatar can be un-frozen (movement re-enabled).
-(Aurora-Sim only)
aaFreezeAvatar(key ID)
Where ID = avatar uuid. If combat permission are granted then avatar can be frozen (no movement).
-(Aurora-Sim only)
aaGetTeamMembers(string team)
Return a list of team members. Where team = string of team name.
-(Aurora-Sim only)
POLYMORPHIC FUNCTION.
aaGetLastOwner(string PrimID) returns last owner UUID of PrimID where PrimID = uuid of prim.
AaGetLastOwner() returns last owner uuid of prim containg script.
-(Aurora-Sim only)
aaSayDistance(integer channelID, float Distance, string text)
Where channelID = channel to say on, Distance = float in meters for distance to say, text = string to say.
-(Aurora-Sim only)
aaSayTo(key userID, string text)
Where userID = avatar key, text = string msg. Similar to llOwnerSay but can be directly targeted to an avatar.
-(Aurora-Sim only)
aaGetWalkDisabled(key ID)
Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
-(Aurora-Sim only)
aaSetWalkDisabled(key ID, integer Value)
Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables walk, forcing avatar to fly.
-(Aurora-Sim only)
aaGetFlyDisabled(key ID)
Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
-(Aurora-Sim only)
aaSetFlyDisabled(key ID, integer Value)
Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables flying, forcing avatar to walk.
-(Aurora-Sim only)
aaAvatarFullName2Key(string FullName)
Returns the avatar uuid from their fullname. Where FullName = "Firstname Lastname”.
-(Aurora-Sim only)
aaRaiseError(string message)
Allows you to have errors that end the execution of the event and fire another event in the script.
-(Aurora-Sim only)
aaGetText()
Returns a string of the hover text of an object.
-(Aurora-Sim only)
aaGetTextColor()
Returns the hovertext color in rotation. Use Ex: rotation color = aaGetTextColor() to separate color.x, color.y, color.z, color.s Where s = value of alpha in llSetText.
-(Aurora-Sim only)
aaSetEnv(string EnvName, list Value)
Sets environment values. Where EnvName = ENABLE_GRAVITY, GRAVITY_FORCE_X, GRAVITY_FORCE_Y, GRAVITY_FORCE_Z, ADD_GRAVITY_POINT, ADD_GRAVITY_FORCE, START_TIME_REVERSAL_SAVING,
STOP_TIME_REVERSAL_SAVING, START_TIME_REVERSAL, STOP_TIME_REVERSAL.
-(Aurora-Sim only)
aaGetIsInfiniteRegion()
Returns TRUE or FALSE if region is an infinite region.
-(Aurora-Sim only)
aaSetCharacterStat( ID, StatName, statValue)
Sets Character Stats. Where ID = avatar uuid, StatName = stat to change, statValue the value to change it to.
-(Aurora-Sim only)
aaAllRegionInstanceSay(integer channelID, string text)
-(Aurora-Sim only)
aaWindlightGetDayCycle()
Returns a List of settings
-(Aurora-Sim only)
aaWindlightAddDayCycleFrame(float dayCyclePosition, integer dayCycleFrameToCopy)
Returns TRUE / FALSE on success status
-(Aurora-Sim only)
aaWindlightRemoveDayCycleFrame(int dayCycleFrame)
Returns TRUE / FALSE on success status
-(Aurora-Sim only)
aaWindlightSetScene(list list)
aaWindlightSetScene(integer dayCycleIndex, list list)
Returns TRUE/FALSE on success
-(Aurora-Sim only)
aaWindlightGetScene(list rules)
aaWindlightGetScene(integer dayCycleKeyFrame, list rules)
Returns a list
-(Aurora-Sim only)
aaWindlightGetSceneIsStatic()
Returns TRUE / FALSE
-(Aurora-Sim only)
aaWindlightGetSceneDayCycleKeyFrameCount()
Returns integer value
-(Aurora-Sim only)
botGetWaitingTime(integer waitTime)
Returns waitTime as vector.
-(Aurora-Sim only)
botSetMap(key keyOfBot, list positions, list movementType, integer flags)
keyOfBot = bot uuid, positions = list of position vectors, movementType = corresponding list of move modes: 0 – walk, 1 – fly,
flags = BOT_FOLLOW_FLAG_NONE and BOT_FOLLOW_FLAG_INDEFINITELY.
-(Aurora-Sim only)
botCreateBot(string FirstName, string LastName, key idToClone, vector startPos)
Where FirstName and LastName = strings for new bot name. idToClone = uuid of prebuild avatar to clone OR another existing avatar. startPos = vector of starting position on region.
-(Aurora-Sim only)
botRemoveBot(key botID)
Where botID = uuid of bot. Removes bot identified by botID.
-(Aurora-Sim only)
botPauseMovement(key botID)
Where botID = bot uuid. Pauses bot at current position.
-(Aurora-Sim only)
botResumeMovement(key botID)
Where botID = bot uuid. Resumes bot movement.
-(Aurora-Sim only)
botFollowAvatar(key botID, string avName, float startFollowDistance, float endFollowDistance)
Where botID = bot uuid. AvName = sting of avatar name OR avatar uuid. StartFollowDistance = distance to start following from. EndFollowDistance = distance to stop following avatar.
-(Aurora-Sim only)
botStopFollowAvatar(key botID)
Where botID = bot uuid. Stops bot from following an avatar.
-(Aurora-Sim only)
botSendChatMessage(key botID, string message, integer channel, integer sayType)
Where botID = bot uuid. Message = string msg. Channel = channel to speak on. SayType = (0=whisper, 1=say, 2=shout).
-(Aurora-Sim only)
botSendIM(string bot, string user, string message)
Send IM to bot.
-(Aurora-Sim only)
botSetShouldFly(key botID, integer ShouldFly)
Where botID = bot uuid. ShouldFly = TRUE/FALSE. Enables or disables flight mode.
-(Aurora-Sim only)
botSitObject(key botID, key objectID, vector offset)
Where botID = bot uuid, objectID = uuid of object to sit on, offset = Vector for sit position (note that VECTOR_ZERO = default sit pos).
-(Aurora-Sim only)
botStandUp(key botID)
Where botID = bot uuid. Command bot to stand up.
-(Aurora-Sim only)
botTouchObject(key botID, key objectID)
Where botID = bot uuid, objectID = object uuid. Causes bot to touch object identified.
-(Aurora-Sim only)
botAddTag(key botID, string tag)
Where botID = bot uuid, tag = string tag over bot.
-(Aurora-Sim only)
botGetBotsWithTag(string tag)
Where tag = tag string to match. Return a list of bot UUID's in region with the matching tag.
-(Aurora-Sim only)
botRemoveBotsWithTag(string tag)
Where tag = tag string to match. Removes bot's matching the tag.
-(Aurora-Sim only)
-
+
Item currently not set
diff --git a/indra/newview/skins/default/xui/es/strings.xml b/indra/newview/skins/default/xui/es/strings.xml
index c2c361fe8..d318af75d 100644
--- a/indra/newview/skins/default/xui/es/strings.xml
+++ b/indra/newview/skins/default/xui/es/strings.xml
@@ -2166,8 +2166,8 @@ Sets the given permission mask to the new value on the root object the task is a
Please keep LL-LSL above this section
** DATA SOURCES **
OpenSim OS Functions: \OpenSim\Region\ScriptEngine\Shared\Api\Interface\IOSSL_Api.cs
- Aurora-Sim AA Functions: \Aurora\AuroraDotNetEngine\APIs\AA_API.cs
- Aurora-Sim BOT Functions: \Aurora\BotManager\Bot_API.cs
+ WhiteCore AA Functions: \WhiteCore\ScriptEngine\DotNetEngine\APIs\AA\AA_API.cs
+ WhiteCore BOT Functions: \WhiteCore\BotManager\Bot_API.cs
-->
@@ -2796,319 +2796,259 @@ list lsGetWindlightScene(list rules)
Get the current WindLight settings.
(Reguires LightShare Enabled Viewer)
-
osReturnObject(key userID)
Returns object to specified avatars UUID.
-(Aurora-Sim only)
osReturnObjects(float Parameter)
Returns group of objects. Parameter's are numeric, values are owner objects = 0, everyone except owner objects = 1, group objects = 2.
-(Aurora-Sim only)
osShutDown()
Shut's down current Simulator. Authorized Admin Only by config.
-(Aurora-Sim only)
osAddAgentToGroup(key avatarID, string group_name, string role_name)
Adds an avatar to a group. Where group_name = name of the target group, role_name = role to assign within the group.
-(Aurora-Sim only)
osRezObject(string inventory, vector position, vector velocity, rotation rot, integer param, integer isRezAtRoot, integer doRecoil, integer SetDieAtEdge, integer CheckPos)
Where inventory = object to rez. Position = vector to rez object. Velocity = initial velocity. Rot = initial rotation. Param = onrez event.
IzAtRoot = TRUE/FALSE flag changes llRezAtRoot to llRezObject. doRecoil =TRUE/FALSE to push avatar. SetDieAtEdge = TRUE/FALSE for rezzed object to die at edge of region.
CheckPos = TRUE/FALSE enable/disable 10m rez limit.
-(Aurora-Sim only)
aaSetCloudDensity(float density)
AaSetCloudDensity(0.5) Where float density values are 0.0 = no cloud to 1.0 = 100% cloud.
-(Aurora-Sim only)
aUpdateDatabase(string Key, string value, string token)
Where Key = database field name, xmlDataToPutIntoTheDatabase = serialized XML data, Token = data-password
-(Aurora-Sim only)
aaQueryDatabase(string Key, string Token)
Returns a list with first value is the token, the second the Key, and the third the value
Where Key = database field name, Token = data-password
-(Aurora-Sim only)
aaDeserializeXMLValues(string xmlData)
Returns a list of Values from XML data. Where xmlData = xml formatted data Values.
-(Aurora-Sim only)
aaDeserializeXMLKeys(string xmlData)
Returns a list of keys from XML data. Where xmlData = xml formatted data keys.
-(Aurora-Sim only)
aaSetConeOfSilence(float radius)
Where radius = metres radius from centre of scripted item. This creates an area that sounds can only be heard by the people within the area(radius) and not heard outside and visa-versa.
-(Aurora-Sim only)
aaSerializeXML(list keys, list values)
Returns xml formatted string of the keys and values. Where keys = list of keys in the database, values = fields to retrieve from database.
-(Aurora-Sim only)
aaGetTeam(key uuid)
Returns a string of avatars team name. Where uuid = avatar key.
-(Aurora-Sim only)
aaGetHealth(key uuid)
Returns float value (0.0 to 100.0) of current health. Where uuid = avatar key.
-(Aurora-Sim only)
aaJoinCombat(key uuid)
Where uuid = avatar key. If (PERMISSION_COMBAT == PERMISSION_COMBAT) and permission is granted then join combat.
-(Aurora-Sim only)
aaLeaveCombat(key uuid)
Where uuid = avatar key.
-(Aurora-Sim only)
aaJoinCombatTeam(key uuid, string team)
Where uuid = key of avatar, team = string of the team name.
-(Aurora-Sim only)
aaRequestCombatPermission(key ID)
Where ID = avatar uuid. Requests target avatar for Permissions to enter into combat mode.
Raises a run_time_permissions event. (PERMISSION_COMBAT == PERMISSION_COMBAT).
-(Aurora-Sim only)
aaThawAvatar(key ID)
Where ID = avatar uuid. If combat permission are granted then avatar can be un-frozen (movement re-enabled).
-(Aurora-Sim only)
aaFreezeAvatar(key ID)
Where ID = avatar uuid. If combat permission are granted then avatar can be frozen (no movement).
-(Aurora-Sim only)
aaGetTeamMembers(string team)
Return a list of team members. Where team = string of team name.
-(Aurora-Sim only)
POLYMORPHIC FUNCTION.
aaGetLastOwner(string PrimID) returns last owner UUID of PrimID where PrimID = uuid of prim.
AaGetLastOwner() returns last owner uuid of prim containg script.
-(Aurora-Sim only)
aaSayDistance(integer channelID, float Distance, string text)
Where channelID = channel to say on, Distance = float in meters for distance to say, text = string to say.
-(Aurora-Sim only)
aaSayTo(key userID, string text)
Where userID = avatar key, text = string msg. Similar to llOwnerSay but can be directly targeted to an avatar.
-(Aurora-Sim only)
aaGetWalkDisabled(key ID)
Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
-(Aurora-Sim only)
aaSetWalkDisabled(key ID, integer Value)
Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables walk, forcing avatar to fly.
-(Aurora-Sim only)
aaGetFlyDisabled(key ID)
Returns integer of TRUE or FALSE for specifid ID. Where ID = avatar uuid.
-(Aurora-Sim only)
aaSetFlyDisabled(key ID, integer Value)
Where ID = avatar uuid, Value = TRUE or FALSE. If PERMISSION_COMBAT is accepted, this disables flying, forcing avatar to walk.
-(Aurora-Sim only)
aaAvatarFullName2Key(string FullName)
Returns the avatar uuid from their fullname. Where FullName = "Firstname Lastname”.
-(Aurora-Sim only)
aaRaiseError(string message)
Allows you to have errors that end the execution of the event and fire another event in the script.
-(Aurora-Sim only)
aaGetText()
Returns a string of the hover text of an object.
-(Aurora-Sim only)
aaGetTextColor()
Returns the hovertext color in rotation. Use Ex: rotation color = aaGetTextColor() to separate color.x, color.y, color.z, color.s Where s = value of alpha in llSetText.
-(Aurora-Sim only)
aaSetEnv(string EnvName, list Value)
Sets environment values. Where EnvName = ENABLE_GRAVITY, GRAVITY_FORCE_X, GRAVITY_FORCE_Y, GRAVITY_FORCE_Z, ADD_GRAVITY_POINT, ADD_GRAVITY_FORCE, START_TIME_REVERSAL_SAVING,
STOP_TIME_REVERSAL_SAVING, START_TIME_REVERSAL, STOP_TIME_REVERSAL.
-(Aurora-Sim only)
aaGetIsInfiniteRegion()
Returns TRUE or FALSE if region is an infinite region.
-(Aurora-Sim only)
aaSetCharacterStat( ID, StatName, statValue)
Sets Character Stats. Where ID = avatar uuid, StatName = stat to change, statValue the value to change it to.
-(Aurora-Sim only)
aaAllRegionInstanceSay(integer channelID, string text)
-(Aurora-Sim only)
aaWindlightGetDayCycle()
Returns a List of settings
-(Aurora-Sim only)
aaWindlightAddDayCycleFrame(float dayCyclePosition, integer dayCycleFrameToCopy)
Returns TRUE / FALSE on success status
-(Aurora-Sim only)
aaWindlightRemoveDayCycleFrame(int dayCycleFrame)
Returns TRUE / FALSE on success status
-(Aurora-Sim only)
aaWindlightSetScene(list list)
aaWindlightSetScene(integer dayCycleIndex, list list)
Returns TRUE/FALSE on success
-(Aurora-Sim only)
aaWindlightGetScene(list rules)
aaWindlightGetScene(integer dayCycleKeyFrame, list rules)
Returns a list
-(Aurora-Sim only)
aaWindlightGetSceneIsStatic()
Returns TRUE / FALSE
-(Aurora-Sim only)
aaWindlightGetSceneDayCycleKeyFrameCount()
Returns integer value
-(Aurora-Sim only)
botGetWaitingTime(integer waitTime)
Returns waitTime as vector.
-(Aurora-Sim only)
botSetMap(key keyOfBot, list positions, list movementType, integer flags)
keyOfBot = bot uuid, positions = list of position vectors, movementType = corresponding list of move modes: 0 – walk, 1 – fly,
flags = BOT_FOLLOW_FLAG_NONE and BOT_FOLLOW_FLAG_INDEFINITELY.
-(Aurora-Sim only)
botCreateBot(string FirstName, string LastName, key idToClone, vector startPos)
Where FirstName and LastName = strings for new bot name. idToClone = uuid of prebuild avatar to clone OR another existing avatar. startPos = vector of starting position on region.
-(Aurora-Sim only)
botRemoveBot(key botID)
Where botID = uuid of bot. Removes bot identified by botID.
-(Aurora-Sim only)
botPauseMovement(key botID)
Where botID = bot uuid. Pauses bot at current position.
-(Aurora-Sim only)
botResumeMovement(key botID)
Where botID = bot uuid. Resumes bot movement.
-(Aurora-Sim only)
botFollowAvatar(key botID, string avName, float startFollowDistance, float endFollowDistance)
Where botID = bot uuid. AvName = sting of avatar name OR avatar uuid. StartFollowDistance = distance to start following from. EndFollowDistance = distance to stop following avatar.
-(Aurora-Sim only)
botStopFollowAvatar(key botID)
Where botID = bot uuid. Stops bot from following an avatar.
-(Aurora-Sim only)
botSendChatMessage(key botID, string message, integer channel, integer sayType)
Where botID = bot uuid. Message = string msg. Channel = channel to speak on. SayType = (0=whisper, 1=say, 2=shout).
-(Aurora-Sim only)
botSendIM(string bot, string user, string message)
Send IM to bot.
-(Aurora-Sim only)
botSetShouldFly(key botID, integer ShouldFly)
Where botID = bot uuid. ShouldFly = TRUE/FALSE. Enables or disables flight mode.
-(Aurora-Sim only)
botSitObject(key botID, key objectID, vector offset)
Where botID = bot uuid, objectID = uuid of object to sit on, offset = Vector for sit position (note that VECTOR_ZERO = default sit pos).
-(Aurora-Sim only)
botStandUp(key botID)
Where botID = bot uuid. Command bot to stand up.
-(Aurora-Sim only)
botTouchObject(key botID, key objectID)
Where botID = bot uuid, objectID = object uuid. Causes bot to touch object identified.
-(Aurora-Sim only)
botAddTag(key botID, string tag)
Where botID = bot uuid, tag = string tag over bot.
-(Aurora-Sim only)
botGetBotsWithTag(string tag)
Where tag = tag string to match. Return a list of bot UUID's in region with the matching tag.
-(Aurora-Sim only)
botRemoveBotsWithTag(string tag)
Where tag = tag string to match. Removes bot's matching the tag.
-(Aurora-Sim only)
-
+
No definido actualmente
diff --git a/indra/newview/llenvmanager.cpp b/indra/newview/llenvmanager.cpp
index 4abd7fc8e..d2fb204cc 100644
--- a/indra/newview/llenvmanager.cpp
+++ b/indra/newview/llenvmanager.cpp
@@ -505,7 +505,7 @@ void LLEnvManagerNew::onRegionSettingsResponse(const LLSD& content)
mRegionSettingsChangeSignal();
// reset
- if (!gHippoGridManager->getConnectedGrid()->isAurora()) // On Aurora, the region says when to refresh
+ if (!gHippoGridManager->getConnectedGrid()->isWhiteCore()) // On WhiteCore, the region says when to refresh
mInterpNextChangeMessage = false;
}
@@ -704,7 +704,7 @@ void LLEnvManagerNew::onRegionChange()
}
}
-// Aurora-sim windlight refresh
+// WhiteCore windlight refresh
class WindLightRefresh : public LLHTTPNode
{
/*virtual*/ void post(LLHTTPNode::ResponsePtr response, const LLSD& context, const LLSD& input) const